package org.benchkit;

/**
 * The interface for a class that is some kind of Benchmark.
 * 
 * The {@link BenchmarkRunner} will call into these methods, when running the
 * benchmark.
 * 
 * @author cvh
 * @see SimpleBenchmark
 */
public interface Benchmark {

  /**
   * Perform the one-time setup of the benchmark.
   * 
   * This method is only called once per benchmark, and numerous calls to
   * {@link #runSession(Recorder)} will follow it.
   */
  void setUp() throws Exception;

  /**
   * Run a benchmark session. This method will be called many times after the
   * initial call to {@link #setUp()}.
   * 
   * @param mainRecorder The main recorder that is used to take measures in
   * this benchmark session. Remember that {@link Recorder recorders} are not
   * thread-safe. If you want to record from threads, 
   * @throws Exception
   */
  void runSession(Recorder mainRecorder) throws Exception;

  /**
   * Called once all of the benchmark sessions have run, and been recorded.
   * 
   * This method is only called once, at the end of a benchmark. No more calls
   * to {@link #runSession(Recorder)} will be made after a call to this method.
   * @throws Exception
   */
  void tearDown() throws Exception;
}
