package org.benchkit;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotate the parameters in a constructor to a Benchmark class, to make use
 * of the parameter injection feature of {@link BenchmarkRunner#run(Class)}
 * feature.
 * 
 * The {@link #value()} is the name of the system property from which the
 * comma separated list of values should be read. All possible combinations of
 * values will be tried.
 * 
 * The {@link #defaults()} is the value that will be used if no system property
 * with the given name has been set. 
 * 
 * A minimum amount of type coercion is applied, such that the following
 * types of arguments are supported: Enums, Strings and all non-array primitive
 * types.
 * @author cvh
 *
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.PARAMETER)
public @interface Param {
  String value();
  String defaults() default "";
}
