package org.benchkit;

import java.io.PrintStream;
import java.util.Arrays;

import org.HdrHistogram.HistogramData;

/**
 * A {@link Reporter} that prints the results to System.out.
 * @author cvh
 */
public class PrintingReporter implements Reporter {
  
  private final PrintStream out;
  private Object[] arguments;
  
  public PrintingReporter() {
    this(System.out);
  }
  
  public PrintingReporter(PrintStream out) {
    this.out = out;
  }

  @Override
  public void report(RecordingData data) {
    String benchmarkName = data.getBenchmarkName();
    HistogramData histogramData = data.getHisogram().getHistogramData();
    double conversionFactor = data.getDatapointConversionFactor();
    long elapsedRuntimeMillis = data.getElapsedRuntimeMillis();
    long totalRecordings = data.getTotalRecordings();
    
    if (arguments != null) {
      benchmarkName = benchmarkName + Arrays.toString(arguments);
    }
    out.println(benchmarkName);
    
    histogramData.outputPercentileDistribution(out, 1, conversionFactor);
    
    double elapsedRuntimeSeconds = elapsedRuntimeMillis / 1000.0;
    double opssec = totalRecordings / elapsedRuntimeSeconds;
    
    out.printf("#[Ops/Sec = % ,10.1f]\n\n", opssec);
  }

  @Override
  public void clear() {
    arguments = null;
  }

  @Override
  public void setArguments(Object[] arguments) {
    this.arguments = arguments;
  }
}
