package org.benchkit;

import java.util.Collection;
import java.util.Iterator;
import java.util.List;

class Seq<T> implements Iterable<T> {
  final T head;
  final Seq<T> tail;
  
  Seq(T head, Seq<T> tail) {
    this.head = head;
    this.tail = tail;
  }
  
  Seq(List<T> list) {
    if (list.isEmpty()) {
      head = null;
      tail = null;
    } else {
      head = list.get(0);
      tail = list.size() > 1? new Seq<T>(list, 1) : null;
    }
  }
  
  Seq(List<T> list, int index) {
    head = list.get(index);
    index++;
    if (index == list.size()) {
      tail = null;
    } else {
      tail = new Seq<T>(list, index);
    }
  }
  
  <C extends Collection<T>> C into(C coll) {
    if (head != null) {
      coll.add(head);
    }
    if (tail != null) {
      tail.into(coll);
    }
    return coll;
  }

  @Override
  public Iterator<T> iterator() {
    return new Iterator<T>() {
      Seq<T> curr = Seq.this;
      @Override
      public boolean hasNext() {
        return curr != null;
      }

      @Override
      public T next() {
        T obj = curr.head;
        curr = curr.tail;
        return obj;
      }

      @Override
      public void remove() {
        throw new UnsupportedOperationException();
      }
    };
  }

  @Override
  public String toString() {
    return "Seq [head=" + head + ", tail=" + tail + "]";
  }
}
