package org.benchkit.htmlchartsreporter;

import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

public class Chart implements Iterable<DataSeries> {
  private static final Hsl[] colours = ChartRenderUtil.generateColours();

  private final int id;
  private final Map<String, DataSeries> seriesPoints;
  private int seriesCounter = 0;

  public Chart(int id) {
    this.id = id;
    seriesPoints = new HashMap<String, DataSeries>();
  }

  public void addDataPoint(DataPoint dataPoint) {
    DataSeries series = seriesPoints.get(dataPoint.seriesName);
    if (series == null) {
      Hsl colour = colours[seriesCounter % colours.length];
      seriesCounter++;
      series = new DataSeries(seriesCounter, dataPoint.seriesName, colour);
      seriesPoints.put(dataPoint.seriesName, series);
    }
    series.add(dataPoint);
  }

  public int getId() {
    return id;
  }
  
  private Collection<DataSeries> getSeriesData() {
    return seriesPoints.values();
  }

  @Override
  public Iterator<DataSeries> iterator() {
    return getSeriesData().iterator();
  }
}
