package org.benchkit.htmlchartsreporter;

import org.HdrHistogram.HistogramData;
import org.benchkit.RecordingData;

public class DataPoint {

  public final String seriesName;
  public final Comparable<Object> xvalue;
  public final double opssec;
  public final RecordingData data;
  public final double latencyMean;
  public final long latencyMax;
  public final long latencyMin;
  public final double latencyStddev;
  public final long latency95;
  public final long latency99;
  public final long latency999;
  public final long latency9999;
  public double factorConvertingLatencyToMillis;

  public DataPoint(
      String seriesName,
      Comparable<Object> xvalue,
      RecordingData data) {
    this.seriesName = seriesName;
    this.xvalue = xvalue;
    
    long elapsedRuntimeMillis = data.getElapsedRuntimeMillis();
    long totalRecordings = data.getTotalRecordings();
    double elapsedRuntimeSeconds = elapsedRuntimeMillis / 1000.0;
    this.opssec = totalRecordings / elapsedRuntimeSeconds;
    this.data = data;
    
    HistogramData histogram = data.getHisogram().getHistogramData();
    latencyMean = histogram.getMean();
    latencyMax = data.getMaxRecordedValue();
    latencyMin = data.getMinRecordedValue();
    latencyStddev = histogram.getStdDeviation();
    latency95 = histogram.getValueAtPercentile(95.0);
    latency99 = histogram.getValueAtPercentile(99.0);
    latency999 = histogram.getValueAtPercentile(99.9);
    latency9999 = histogram.getValueAtPercentile(99.99);
    factorConvertingLatencyToMillis = data.getDatapointConversionFactor();
  }
}
