package org.benchkit.htmlchartsreporter;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import java.util.NavigableMap;
import java.util.TreeMap;

public class DataSeries implements Iterable<List<DataPoint>> {
  private final int id;
  private final String name;
  private final Hsl colour;
  private final NavigableMap<Comparable<?>, List<DataPoint>> series;
  
  public DataSeries(int id, String name, Hsl colour) {
    this.id = id;
    this.name = name;
    this.colour = colour;
    this.series = new TreeMap<Comparable<?>, List<DataPoint>>();
  }

  public void add(DataPoint dataPoint) {
    List<DataPoint> points = series.get(dataPoint.xvalue);
    if (points == null) {
      points = new ArrayList<DataPoint>();
      series.put(dataPoint.xvalue, points);
    }
    points.add(dataPoint);
  }

  public int getId() {
    return id;
  }

  public Hsl getSeriesColour() {
    return colour;
  }

  public String getSeriesName() {
    return name;
  }

  @Override
  public Iterator<List<DataPoint>> iterator() {
    return series.values().iterator();
  }

  public int countPotentialCurves() {
    return series.firstEntry().getValue().size();
  }

  public void sortDataPoints(Comparator<DataPoint> comparator) {
    for (List<DataPoint> points : this) {
      Collections.sort(points, comparator);
    }
  }
}
